#+title: Natural script writing with Guile
#+subtitle: The newest step on my path towards the perfect script writing syntax
#+options: toc:nil H:2 ^:nil
#+LaTeX_CLASS: beamer
#+LaTeX_CLASS_OPTIONS: [presentation]
#+LaTeX_HEADER:\newcounter{framenumberwithoutappendix}
#+COLUMNS: %45ITEM %10BEAMER_env(Env) %10BEAMER_act(Act) %4BEAMER_col(Col) %8BEAMER_opt(Opt)
#+PROPERTY: BEAMER_col_ALL 0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 0.0 :ETC
#+STARTUP: beamer
#+latex_header: \usetheme{Berlin}\usecolortheme{dove}
#+LaTeX: \definecolor{bg}{rgb}{0.98,0.98,0.98}


* Introduction
** Hello
#+BEGIN_SRC scheme :noweb strip-export :tangle natural-script-writing-1-intro.w
<<prep>>
Enter : The Audience
        The Presenter
        Arne Babenhauserheide

Arne Babenhauserheide :imaginary:
    Sorry for not being here in person.
    My deepest gratitude to the presenter!

The Presenter
    Hello ,(read-line) ..

The Audience
    (Applause!) ; :)
#+END_SRC

** Hello (output)

[[./natural-script-writing-1-hello-screenshot.png]]

** Scheme-Warning

This is actual Guile code, parsed to Scheme at read time.

#+BEGIN_SRC scheme
(import (language wisp spec))
#+END_SRC

For more information, see [[http://draketo.de/english/wisp][draketo.de/english/wisp]]

* Prior Art
** Prior Art

Where we start from.

/@Presenter: Just for impression. Best give these slides 15s each./

** WML: from Battle for Wesnoth
#+BEGIN_SRC ini
    name=start
    [message]
        speaker=MyLeader
        message= _ "I see the orcs!"
    [/message]
    [message]
        speaker=EnemyLeader
        message= _ "Grrrr!"
    [/message]
#+END_SRC
- [[https://wiki.wesnoth.org/WML_for_Complete_Beginners][wiki.wesnoth.org/WML_for_Complete_Beginners]]

#+latex: \hspace*{-2.1em}
#+attr_latex: :height 2em
[[./portrait-arne.png]]
#+latex: \hspace*{0.1em}
*Verbose, but dialogs are not its main purpose.*

** SCUMM: from Monkey Island

#+BEGIN_SRC sh
cut-scene {
    ...
    actor nurse-edna in-room edna-bedroom at 60,20
    camera-follow nurse-edna
    actor nurse-edna walk-to 30,20
    wait-for-actor nurse-edna
    say-line nurse-edna "WHATS'S YOUR POINT ED!!!"
    wait-for-talking nurse-edna
    ...
}
#+END_SRC

- [[https://en.wikipedia.org/wiki/SCUMM][en.wikipedia.org/wiki/SCUMM]]

#+latex: \hspace*{-2.1em}
#+attr_latex: :height 2em
[[./portrait-arne.png]]
#+latex: \hspace*{0.1em}
*Not bad, but something is odd (personal impression).*
** Python: My last try

#+BEGIN_SRC python
from rpg_lib.textrpg import *
name = ask("What's your name?")
char2 = Char(source="tag:1w6.org,2008:Nasfar")
char1 = Char(source="tag:1w6.org,2008:" + name)

story("""A hero is born to save us.
""")

char2.say("""I only know I want to live. 
""")

char1.say("""You're a wimp!
""")
#+END_SRC

#+latex: \hspace*{-2.1em}
#+attr_latex: :height 2em
[[./portrait-arne.png]]
#+latex: \hspace*{0.1em}
*All these quotes, no action between words.*

** Spels with Lisp: from Casting Spels with Emacs

#+latex: \small

#+BEGIN_SRC elisp
  (setq map '((living-room 
               (you are in the living room of a wizards house -
                there is a wizard snoring loudly on the couch -)
               (west door garden))))


  (defun describe-location (location map)
    (second (assoc location map)))

  (describe-location 'living-room map)
#+END_SRC

- [[http://www.lisperati.com/casting-spels-emacs/html/casting-spels-emacs-1.html][lisperati.com/casting-spels-emacs/html/casting-spels-emacs-1.html]]

#+latex: \normalsize

#+latex: \hspace*{-2.1em}
#+attr_latex: :height 2em
[[./portrait-arne.png]]
#+latex: \hspace*{0.1em}
*Close, so close.*

* Examples
** Examples

Where I am.
** Enter three witches (with inline-code)
#+BEGIN_SRC scheme :noweb strip-export :tangle natural-script-writing-3-three-witches-color.w
  <<prep>>
  Enter : First Witch
          Second Witch

  First Witch
      When shall we three meet again
      In ,(color 'cyan) thunder, ,(color 'white) 
        . lightning, ,(color #f) or in ,(color 'blue) 
        . rain? ,(color #f)

  Second Witch :resolute
      When the hurlyburly's done, (we ,(+ 1 2))
      ; ... inline-code is executed when it is displayed
#+END_SRC

** Enter three witches (with inline-code, output)

[[./natural-script-writing-3-three-witches-color-screenshot.png]]

** Duel
#+BEGIN_SRC scheme :noweb strip-export :tangle natural-script-writing-4-duel.w
<<prep>>
Enter : Galtag Nimbleday
        Lowlife Pirate
        choose your answer

define answers
  `
    : You fight like a Dairy Farmer!
      How appropriate! You fight like a cow!
      And I've got a little TIP for you, get the POINT?
; ... (define (Duel ...) ...) for interaction
Duel
  Galtag Nimbleday
  Lowlife Pirate

#+END_SRC

** Duel (output)

#+attr_latex: :width 1.0\linewidth
[[./natural-script-writing-4-duel-screenshot.png]]


** Summary

It works. I’m happy 
#+latex: \(\ddot \smile\)

Next step: Making Games.

Main complication: Shipping Games made with Guile.

Find the code in the org-mode source and in the wisp-repo: http://bitbucket.org/ArneBab/wisp/
** Thank you!
#+latex: \centering \(\ddot \smile\)

* Appendix

\appendix

** Three Witches (basic)
#+BEGIN_SRC scheme :noweb strip-export :tangle natural-script-writing-2-three-witches-basic.w
    <<prep>>
    Enter : First Witch
            Second Witch
            Third Witch

    First Witch
        When shall we three meet again
        In thunder, lightning, or in rain?
  
    Second Witch :resolute
        When the hurlyburly's done,
        When the battle's lost and won.

    Third Witch
        That will be ere the set of sun.
#+END_SRC

** Three witches (basic, output)

[[./natural-script-writing-2-three-witches-basic-screenshot.png]]



** Prep
#+BEGIN_SRC sh :noweb-ref prep
#!/usr/bin/env bash
# guile-2.0 ~/wisp/wisp.scm ~/wisp/examples/enter-three-witches.w > ~/wisp/examples/enter-three-witches.scm
guile-2.0 ~/wisp/examples/enter-three-witches.scm
exec guile-2.0 -L ~/wisp --language=wisp -s "$0" "$@"
; !#
import : examples enter-three-witches
         ice-9 rdelim
#+END_SRC

#+latex_header: \usepackage{hyperref}
#+LATEX_HEADER: \usepackage{xcolor}

#+LATEX_HEADER: \setlength{\parindent}{0cm}
#+LATEX_HEADER: \setlength{\parskip}{0.5em}

# unicode input
#+LATEX_HEADER: \usepackage{uniinput}
#+LATEX_HEADER: \DeclareUnicodeCharacter{B7}{\ensuremath{\cdot}}

#+LATEX_HEADER: \usepackage{natbib}
#+LATEX_HEADER: \usepackage{morefloats}
#+LATEX_HEADER: \hypersetup{
#+LATEX_HEADER:     colorlinks,
#+LATEX_HEADER:     linkcolor={red!50!black},
#+LATEX_HEADER:     citecolor={blue!30!black},
#+LATEX_HEADER:     urlcolor={blue!50!black}
#+LATEX_HEADER: }
#+latex_header: \usepackage[protrusion=true,expansion=true]{microtype}



# Local Variables:
# org-confirm-babel-evaluate: nil
# org-export-allow-bind-keywords: t
# org-babel-noweb-wrap-start: "<<"
# org-babel-noweb-wrap-end: ">>"
# End:
